from distutils.core import setup
setup(
    name="alsolib",
    version="0.5.5",
    description="学而思爱搜浏览器功能库0.5.5，下载失败请切换python原版,©爱搜浏览器团队 版权所有",
    author="asunc",
    author_email="3182305655@qq.com",
    py_modules=["alsolib\\alsolib",'alsolib\\alsoapi']
)